plot.forest: Plot forest attributes

View source: R/plot.forest.R

plot.forestR Documentation

Plot forest attributes

Description

Function for plotting vertical forest profiles.

Usage

## S3 method for class 'forest'
plot(
  x,
  SpParams,
  type = "LeafAreaDensity",
  byCohorts = FALSE,
  bySpecies = FALSE,
  includeHerbs = FALSE,
  includeMistletoes = FALSE,
  ...
)

## S3 method for class 'forest'
shinyplot(x, SpParams, ...)

Arguments

x

An object of class forest.

SpParams

A data frame with species parameters (see SpParamsMED).

type

A string of the plot type: "LeafAreaDensity", "RootDistribution", "FuelBulkDensity", "PARExtinction", "SWRExtinction" or "WindExtinction".

byCohorts

A logical flag to separate profiles for each cohort.

bySpecies

A logical flag to aggregate results by species.

includeHerbs

A logical flag to include herbaceous layer in the profile.

includeMistletoes

Include hemi-parasitic plants (mistletoes) in the profile.

...

Additional parameters to vertical profiles

Details

The function is a common wrapper to specialized internal functions (see vprofile_leafAreaDensity).

Value

A ggplot or a shiny application, depending on the function.

Author(s)

Miquel De Cáceres Ainsa, CREAF

See Also

forest, summary.forest, vprofile_leafAreaDensity

Examples

data(exampleforest)
data(SpParamsMED)
plot(exampleforest, SpParamsMED)


medfate documentation built on Sept. 3, 2026, 9:06 a.m.