Function implementing a modification of the DAYCENT carbon decomposition model (Parton et al. 1988, 1993, 1998), inspired by the description given in Chapter 18 of Bonan (2019).
decomposition_DAYCENT(
snags,
litter,
SOC,
paramsLitterDecomposition,
paramsAnatomy,
baseAnnualRates,
annualTurnoverRate,
environmentalConditions,
litterProduction,
sand,
clay,
soilPH,
soilO2 = 1,
cultfac = 1,
tstep = 1,
balanceCheck = FALSE
)A list with two elements:
"HeterotrophicRespiration": A numeric matrix with the heterotrophic respiration (g C·m-2) corresponding to the decomposition in each time step corresponding to different carbon pools:
"SurfaceSnags": Respiration from decomposing snags (i.e. small branches and large wood).
"SurfaceLitter": Respiration from decomposing litter in the surface (i.e. leaves, twigs, small branches and large wood).
"SoilLitter": Respiration from decomposing litter belowground (i.e. coarse roots and fine roots).
"SurfaceMetabolic": Respiration from surface metabolic pool.
"BelowgroundMetabolic": Respiration from belowground metabolic pool.
"SurfaceActive": Respiration from surface active pool.
"BelowgroundActive": Respiration from belowground active pool.
"SurfaceSlow": Respiration from surface slow pool.
"BelowgroundSlow": Respiration from belowground slow pool.
"BelowgroundPassive": Respiration from belowground passive pool.
"DecompositionPools": A numeric matrix with the carbon mass of different carbon pools, all in g C · m-2:
"SmallBranchSnags": Carbon of (standing) small dead branches (diameters between 0.635 cm and 7.5 cm; 10h and 100h fuels).
"LargeWoodSnags": Carbon of (standing) large dead wood (diameters larger than 7.5 cm; 1000h and 10000h fuels).
"LeafLitter": Carbon of leaf litter.
"TwigLitter": Carbon of twig litter.
"SmallBranchLitter": Carbon of (downed) small dead branches (diameters between 0.635 cm and 7.5 cm; 10h and 100h fuels).
"LargeWoodLitter": Carbon of (downed) large dead wood (diameters larger than 7.5 cm; 1000h and 10000h).
"CoarseRootLitter": Carbon of dead coarse roots.
"FineRootLitter": Carbon of fine root litter.
"SurfaceMetabolic": Metabolic carbon in the surface.
"BelowgroundMetabolic": Metabolic carbon in the soil.
"SurfaceActive": Active decomposition carbon pool in the surface.
"BelowgroundActive": Belowground active decomposition carbon pool.
"SurfaceSlow": Slow decomposition carbon pool in the surface.
"BelowgroundSlow": Belowground slow decomposition carbon pool.
"BelowgroundPassive": Belowground passive decomposition carbon pool.
A data frame with initial dead standing (snag) cohort information (see growthInput).
A data frame with initial aboveground and belowground structural carbon pools corresponding to plant cohorts, in g C/m2 (see growthInput).
A named numeric vector with initial metabolic, active, slow and passive carbon pools for surface and soil, in g C/m2 (see growthInput).
A data frame of species-specific litter decomposition parameters (see growthInput).
A data frame of species-specific anatomy parameters (see growthInput).
A named vector of annual decomposition rates, in yr-1 (see defaultControl).
Annual turnover rate, in yr-1 (see defaultControl).
A data frame containing environmental conditions for each time step to simulate:
AirTempperature: Mean air temperature (in Celsius).
AirRelativeHumidity: Mean relative humidity (percent).
SoilTemperature: Mean soil temperature (in Celsius).
SoilMoisture: Mean soil moisture, relative to saturation (0-1).
A data frame containing litter inputs corresponding to time steps:
Step: Integer indicating the time step where litter is generated, corresponding to a row in environmentalConditions.
Species: Mean relative humidity (percent).
Leaves: Leaf litter production (g C·m-2).
Twigs: Twig litter production (g C·m-2).
SmallBranches: Small branch litter production (g C·m-2).
LargeWood: Large wood litter production (g C·m-2).
CoarseRoots: Coarse root litter production (g C·m-2).
FineRoots: Fine root litter production (g C·m-2).
Soil texture (sand and sand) in percent volume (percent).
Soil pH (0-14).
Soil oxygen factor (0-1).
Cultivation factor (0-1).
Time step in days. By default, one day. For annual time steps, use tstep = 365.25.
Flag to print carbon balance check (for debugging).
Miquel De Cáceres Ainsa, CREAF
Roberto Molowny-Horas, CREAF
Inés Delsman Valderrama, CREAF
Species names must match between inputs paramsLitterDecomposition, litter and litterProduction.
IMPORTANT NOTE: Decomposition functions modify the input data (i.e. snags, litter and/or SOC) according to decomposition rates and carbon transfer rates. When used as part of growth simulations,
soil physical and chemical parameters correspond to the uppermost soil layer.
Bonan, G. (2019). Climate change and terrestrial ecosystem modeling. Cambridge University Press, Cambridge, UK.
Parton WJ, Steward JWB, Cole CV (1988). Dynamics of C, N, P and S in grassland soils: a model. Biogeochemistry 5: 109-131.
Parton WJ, Scurlock JMO, Ojima DS, Gilmanov TG, Scoles RJ et al. (1993). Observations and modeling of biomass and soil organic matter dynamics for the grassland biome worldwide. Global Biogeochemical Cycles 7: 785-809.
Parton WJ, Hartman M, Ojima DS, Schimel D (1998). DAYCENT and its land surface submodel: Description and testing. Global and Planetary Change, 19: 35-48.
decomposition_temperatureEffect, growthInput, growth