| emptyforest | R Documentation |
Creates an empty forest object.
emptyforest(
ntree = 0,
nshrub = 0,
nherb = 0,
nseedling = 0,
nseed = 0,
nsnag = 0,
nlitter = 0,
addcolumns = NULL,
SOC = FALSE
)
ntree, nshrub, nherb |
Number of tree, shrub and herb cohorts, respectively. |
nseedling |
Number of species in the seedling bank. |
nseed |
Number of species in the seed bank. |
nsnag |
Number of snag (dead standing) cohorts. |
nlitter |
Number of items in the litter compartment. |
addcolumns |
A character vector with additional columns. Currently allowed are (see
|
SOC |
A boolean flag to initialize SOC data (see |
List elements treeData and shrubData are always created, regardless of the number of cohorts.
In contrast, list elements herbData, seedBank and seedlingBank are only created if nherb, nseed and nseedling are non-zero, respectively.
An empty forest object.
Miquel De Cáceres Ainsa, CREAF
forest, tree2forest, summary.forest, forest_mapWoodyTables, forest_mergeTrees,
plot.forest
# Initializes forest with 2 tree cohorts
emptyforest(ntree = 2)
# Initializes forest with 2 tree cohorts and 1 shrub cohort
emptyforest(ntree = 2, nshrub = 1)
# Initializes with extra column for leaf area index (LAI)
emptyforest(ntree = 2, nshrub = 1, addcolumns = "LAI")
# Initializes forest with 2 tree cohorts, 1 shrub cohort and 1 herbaceous cohort
emptyforest(ntree = 2, nshrub = 1, nherb = 1)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.