| hydraulics_defoliation | R Documentation |
Functions to calculate the proportion of crown defoliation due to hydraulic disconnection.
hydraulics_proportionDefoliationSigmoid(
psiLeaf,
P50,
slope,
criticalLeafPLC = 0.88,
cvLeafP50 = 10
)
hydraulics_proportionDefoliationWeibull(
psiLeaf,
c,
d,
criticalLeafPLC = 0.88,
cvLeafP50 = 10
)
psiLeaf |
Leaf water potential (in MPa). |
P50, slope |
Parameters of the Sigmoid function. |
criticalLeafPLC |
Critical leaf PLC corresponding to defoliation |
cvLeafP50 |
Coefficient of variation (in percent) of leaf P50, to describe the variability in hydraulic vulnerability across crown leaves. |
c, d |
Parameters of the Weibull function. |
The functions assume that crowns are made of a population of leaves whose
hydraulic vulnerability (i.e. the water potential corresponding to 50% loss of conductance)
follows a Gaussian distribution centered on the input P50 and with a known coefficient of variation (cvLeafP50).
The slope parameter (or the c exponent in the case of a Weibull function) is considered constant.
Leaves are hydraulically disconnected, and shedded, when their embolism rate exceeds a critical value (criticalLeafPLC).
The proportion of crown defoliation.
Hervé Cochard, INRAE
Miquel De Cáceres Ainsa, CREAF
hydraulics_conductancefunctions
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.