Function pheno_leafDevelopmentStatus returns the fenological status ([0-1]) of species according to the growth degree days required for leaf flush. Function pheno_updateLeaves updates the status of expanded leaves and dead leaves of object x given the temperature and wind of a given day.
pheno_leafDevelopmentStatus(Sgdd, gdd)
pheno_updateLeaves(x, doy, tmean, wind, Tbase = 5)A numeric vector of growth degree days for leaf budburst (in Celsius).
Growth degree days (in Celsius)
An object of class spwbInput.
Day of the year.
Average day temperature (in Celsius).
Average day wind speed (in m/s).
Base temperature to update growth degree days (in Celsius).
Function pheno_leafDevelopmentStatus returns a vector of values between 0 and 1.