| plot.soil | R Documentation |
Function for plotting water retention or conductivity curves for soil layers.
## S3 method for class 'soil'
plot(
x,
type = "RetentionCurve",
model = "SX",
layer = 1,
relative = TRUE,
to = "SAT",
...
)
x |
Initialized soil object (returned by function |
type |
A string of the plot type: "RetentionCurve" or "ConductivityCurve". |
model |
model Either 'SX' or 'VG' for Saxton's or Van Genuchten's water retention models; or 'both' to plot both retention models. |
layer |
Soil layer to be plotted. |
relative |
Boolean flag to indicate that retention curve should be relative to field capacity or saturation. |
to |
Either 'SAT' (saturation) or 'FC' (field capacity). |
... |
Additional parameters to specific functions |
The function is a common wrapper to specialized internal functions (see soil_retentionCurvePlot).
An object of class ggplot.
Miquel De Cáceres Ainsa, CREAF
soil, summary.soil, soil_retentionCurvePlot
# Initializes soil
s = soil(defaultSoilParams())
plot(s)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.