powered by
Function for plotting water retention or conductivity curves for soil layers.
# S3 method for soil plot( x, type = "RetentionCurve", model = "SX", layer = 1, relative = TRUE, to = "SAT", ... )
An object of class ggplot.
Initialized soil object (returned by function soil).
soil
A string of the plot type: "RetentionCurve" or "ConductivityCurve".
model Either 'SX' or 'VG' for Saxton's or Van Genuchten's water retention models; or 'both' to plot both retention models.
Soil layer to be plotted.
Boolean flag to indicate that retention curve should be relative to field capacity or saturation.
Either 'SAT' (saturation) or 'FC' (field capacity).
Additional parameters to specific functions
Miquel De Cáceres Ainsa, CREAF
The function is a common wrapper to specialized internal functions (see soil_retentionCurvePlot).
soil_retentionCurvePlot
soil, summary.soil, soil_retentionCurvePlot
summary.soil
# Initializes soil s = soil(defaultSoilParams()) plot(s)
Run the code above in your browser using DataLab